@@ -45,3 +45,13 @@ update.check()
 
 def init():
     from cbm.utils import init
+    init.main()
+
+
+def set_api_account(url, username, password):
+    from cbm.utils import config
+    config.set_value(['api', 'url'], url)
+    config.set_value(['api', 'user'], username)
+    config.set_value(['api', 'pass'], password)
+    print("The 'api' key in config/main.json file is updated:")
+    print(config.get_value(['api']))
